@@ -24,19 +24,20 @@ import java.net.URL;
 import java.util.Set;
 
 /**
- * DependencyAnalyzer
- * 
+ * Gets the set of classes referenced by a library given either as a jar file or an exploded directory.
+ *
  * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
- * @version $Id: DependencyAnalyzer.java 661727 2008-05-30 14:21:49Z bentmann $
  */
 public interface DependencyAnalyzer
 {
-    // fields -----------------------------------------------------------------
 
-    String ROLE = DependencyAnalyzer.class.getName();
-
-    // public methods ---------------------------------------------------------
-
-    Set analyze( URL url )
+    /**
+     * <p>analyze.</p>
+     *
+     * @param url the JAR file or directory to analyze
+     * @return the set of class names referenced by the library
+     * @throws IOException if an error occurs reading a JAR or .class file
+     */
+    Set<String> analyze( URL url )
         throws IOException;
 }
